Change 34463 by [EMAIL PROTECTED] on 2008/10/05 17:39:24

        Update copyright year to 2008.

Affected files ...

... //depot/perl/README#32 edit
... //depot/perl/perl.c#875 edit

Differences ...

==== //depot/perl/README#32 (text) ====
Index: perl/README
--- perl/README#31~32608~       2007-12-11 08:55:29.000000000 -0800
+++ perl/README 2008-10-05 10:39:24.000000000 -0700
@@ -1,5 +1,5 @@
 Perl is Copyright (C) 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001,
-2002, 2003, 2004, 2005, 2006, 2007 by Larry Wall and others.
+2002, 2003, 2004, 2005, 2006, 2007, 2008 by Larry Wall and others.
 All rights reserved.
 
 

==== //depot/perl/perl.c#875 (text) ====
Index: perl/perl.c
--- perl/perl.c#874~34234~      2008-08-28 06:11:44.000000000 -0700
+++ perl/perl.c 2008-10-05 10:39:24.000000000 -0700
@@ -1,7 +1,7 @@
 /*    perl.c
  *
  *    Copyright (C) 1993, 1994, 1995, 1996, 1997, 1998, 1999,
  *    2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 by Larry Wall and others
  *
  *    You may distribute under the terms of either the GNU General Public
  *    License or the Artistic License, as specified in the README file.
@@ -3333,7 +3333,7 @@
 #endif
 
        PerlIO_printf(PerlIO_stdout(),
-                     "\n\nCopyright 1987-2007, Larry Wall\n");
+                     "\n\nCopyright 1987-2008, Larry Wall\n");
 #ifdef MACOS_TRADITIONAL
        PerlIO_printf(PerlIO_stdout(),
                      "\nMac OS port Copyright 1991-2002, Matthias Neeracher;\n"
@@ -1,7 +1,7 @@
 /*    perl.c
  *
- *    Copyright (C) 1993, 1994, 1995, 1996, 1997, 1998, 1999,
- *    2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 by Larry Wall and others
+ *    Copyright (C) 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000,
+ *    2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 by Larry Wall and others
  *
  *    You may distribute under the terms of either the GNU General Public
End of Patch.

Reply via email to